==> wevue-2.1.7.tgz: package/vue2/@wevue-tools/src/config/default-page.mixins.js <==

import { pageOnLoad, pageOnShow, pageOnReady, pageOnHide, pageOnUnload, pageOnPullDownRefresh, pageOnShareAppMessage, pageOnReachBottom } from '../lifecycle'
import { _clone } from '../tools'
import { pageFilter } from '../filters/page-data-methods-filter.js'

export function defaultPageMixins() {
    require(`vueroot/pages${__WEVUE_GI.PAGEPATH}.js`)

    /**
     * @lzq
     * 局部组件、混合、指令的添加
     * 插件只能是全局的
     */
    let localComponents = {}
    let localMixins = {}
    let localDirectives = {}
    try {
        localComponents = require(`vueroot/pages${__WEVUE_GI.PAGEPATH}.cdep.js`)
    } catch (error) {
        localComponents = {}
    }
    try {
        localMixins = require(`vueroot/pages${__WEVUE_GI.PAGEPATH}.mdep.js`)
    } catch (error) {
        localMixins = {}
    }
    let localMixinsList = []
    for(let i in localMixins){
        localMixinsList.push(localMixins[i])
    }

    try {
        localDirectives = require(`vueroot/pages${__WEVUE_GI.PAGEPATH}.ddep.js`)
    } catch (error) {
        localDirectives = {}
    }

    
    

    let filterRet = {}
    filterRet = pageFilter()
    return {
        methods: {
            setData(newVal = {}) {
                Object.assign(this, newVal)
            },
            $getAppInstence(){
                return this.$parent
            },
            ...filterRet.methods
        },
        computed: {
            data() {
                return this
            }
        },
        data() {
            return {
                __WEVUE_ROUTE: '',
                ...filterRet.data
            }
        },
        mixins:localMixinsList,
        components: localComponents,
        directives:localDirectives,
        beforeCreate() {

        },
        created() {
            __WEVUE_GI.PVCI[__WEVUE_GI.PAGEPATH] = __WEVUE_GI.PVCI[__WEVUE_GI.PAGEPATH] || {}
            __WEVUE_GI.PVCI[__WEVUE_GI.PAGEPATH] = this
            this.__WEVUE_PATH = this.$route.path

            pageOnLoad.apply(this,[this.$route.query])
            pageOnShow.apply(this)
        },
        beforeMount() {

        },
        mounted() {
            __WEVUE_GI.PVCI[__WEVUE_GI.PAGEPATH] = __WEVUE_GI.PVCI[__WEVUE_GI.PAGEPATH] || {}
            __WEVUE_GI.PVCI[__WEVUE_GI.PAGEPATH] = this

            pageOnReady.apply(this)

        },
        beforeUpdate() {

        },
        updated() {

        },
        beforeDestroy() {
            pageOnHide.apply(this)
        },
        destroyed() {
            pageOnUnload.apply(this)
        },
        ...filterRet.vueAttr

    }
}

==> wevue-2.2.2.tgz: package/vue2/@wevue-tools/src/config/default-page.mixins.js <==

import { pageOnLoad, pageOnShow, pageOnReady, pageOnHide, pageOnUnload, pageOnPullDownRefresh, pageOnShareAppMessage, pageOnReachBottom } from '../lifecycle'
import { _clone } from '../tools'
import { pageFilter } from '../filters/page-data-methods-filter.js'

export function defaultPageMixins(arg={componentsList:{},mixinsList:{},directivesList:{}}) {
    console.warn(arg)
    /**
     * @lzq
     * 局部组件、混合、指令的添加
     * 插件只能是全局的
     */
    let localComponents = {}
    let localMixins = {}
    let localDirectives = {}

    localComponents = arg.componentsList||{}
    localMixins = arg.mixinsList||{}
    let localMixinsList = []
    for(let i in localMixins){
        localMixinsList.push(localMixins[i])
    }

    localDirectives = arg.directivesList||{}

    
    

    let filterRet = {}
    filterRet = pageFilter()
    return {
        methods: {
            setData(newVal = {}) {
                Object.assign(this, newVal)
            },
            $getAppInstence(){
                return this.$parent
            },
            ...filterRet.methods
        },
        computed: {
            data() {
                return this
            }
        },
        data() {
            return {
                __WEVUE_ROUTE: '',
                ...filterRet.data
            }
        },
        mixins:localMixinsList,
        components: localComponents,
        directives:localDirectives,
        beforeCreate() {

        },
        created() {
            __WEVUE_GI.PVCI[__WEVUE_GI.PAGEPATH] = __WEVUE_GI.PVCI[__WEVUE_GI.PAGEPATH] || {}
            __WEVUE_GI.PVCI[__WEVUE_GI.PAGEPATH] = this
            this.__WEVUE_PATH = this.$route.path

            pageOnLoad.apply(this,[this.$route.query])
            pageOnShow.apply(this)
        },
        beforeMount() {

        },
        mounted() {
            __WEVUE_GI.PVCI[__WEVUE_GI.PAGEPATH] = __WEVUE_GI.PVCI[__WEVUE_GI.PAGEPATH] || {}
            __WEVUE_GI.PVCI[__WEVUE_GI.PAGEPATH] = this

            pageOnReady.apply(this)

        },
        beforeUpdate() {

        },
        updated() {

        },
        beforeDestroy() {
            pageOnHide.apply(this)
        },
        destroyed() {
            pageOnUnload.apply(this)
        },
        ...filterRet.vueAttr

    }
}
